@@ -38,7 +38,6 @@
 #include <libedataserverui/e-passwords.h>
 #include <libedataserver/e-account.h>
 #include <e-util/e-dialog-utils.h>
-#include <libmapi/libmapi.h>
 #include "mail/em-config.h"
 #include "exchange-mapi-account-setup.h"
 #include <addressbook/gui/widgets/eab-config.h>
@@ -95,150 +94,22 @@ exchange_mapi_accounts_peek_config_listener ()
 	return config_listener; 
 }
 
-gboolean
-exchange_mapi_delete_profile (const char *profile)
-{
-	enum MAPISTATUS	retval;
-	gboolean result = FALSE; 
-	gchar *profpath = NULL;
-
-	profpath = g_build_filename (g_get_home_dir(), DEFAULT_PROF_PATH, NULL);
-	if (!g_file_test (profpath, G_FILE_TEST_EXISTS)) {
-		g_warning ("No need to delete profile. DB itself is missing \n");
-		result = TRUE;
-		goto cleanup; 
-	}
-
-	retval = MAPIInitialize(profpath); 
-	if (retval == MAPI_E_SESSION_LIMIT)
-	/* do nothing, the profile store is already initialized */
-		; 
-	else if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("MAPIInitialize", GetLastError());
-		goto cleanup; 
-	}
-
-	g_debug ("Deleting profile %s ", profile); 
-	retval = DeleteProfile(profile); 
-	if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("DeleteProfile", GetLastError());
-		goto cleanup; 
-	}
-
-	exchange_mapi_connection_close ();
-	result = TRUE; 
-
-cleanup: 
-	g_free(profpath);
-
-	return result;
-}
-
-gboolean 
-exchange_mapi_create_profile(const char *username, const char *password, const char *domain, const char *server)
-{
-	enum MAPISTATUS	retval;
-	gboolean result = FALSE; 
-	const gchar *workstation = "localhost";
-	gchar *profname = NULL, *profpath = NULL;
-	struct mapi_session *session = NULL;
-
-	d(g_print ("Create profile with %s %s (****) %s %s\n", username, password, domain, server));
-
-	profpath = g_build_filename (g_get_home_dir(), DEFAULT_PROF_PATH, NULL);
-	profname = g_strdup_printf("%s@%s", username, domain);
-
-	if (!g_file_test (profpath, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
-		/* Create a ProfileStore */
-		retval = CreateProfileStore (profpath, LIBMAPI_LDIF_DIR); 
-		if (retval != MAPI_E_SUCCESS) {
-			mapi_errstr("CreateProfileStore", GetLastError());
-			goto cleanup; 
-		}
-	}
-
-	retval = MAPIInitialize(profpath); 
-	if (retval == MAPI_E_SESSION_LIMIT)
-	/* do nothing, the profile store is already initialized */
-		mapi_errstr("MAPIInitialize", GetLastError()); 
-	else if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("MAPIInitialize", GetLastError());
-		goto cleanup; 
-	}
-
-	/* Delete any existing profiles with the same profilename */
-	retval = DeleteProfile(profname); 
-	/* don't bother to check error - it would be valid if we got an error */
-
-	retval = CreateProfile(profname, username, password, 0); 
-	if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("CreateProfile", GetLastError());
-		goto cleanup; 
-	}
-
-	mapi_profile_add_string_attr(profname, "binding", server);
-	mapi_profile_add_string_attr(profname, "workstation", workstation);
-	mapi_profile_add_string_attr(profname, "domain", domain);
-	
-	/* This is only convenient here and should be replaced at some point */
-	mapi_profile_add_string_attr(profname, "codepage", "0x4e4");
-	mapi_profile_add_string_attr(profname, "language", "0x40c");
-	mapi_profile_add_string_attr(profname, "method", "0x409");
-	
-	/* Login now */
-	d(g_print("Logging into the server... "));
-	retval = MapiLogonProvider(&session, profname, NULL, PROVIDER_ID_NSPI); 
-	if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("MapiLogonProvider", GetLastError());
-		g_debug ("Deleting profile %s ", profname); 
-		retval = DeleteProfile(profname); 
-		if (retval != MAPI_E_SUCCESS)
-			mapi_errstr("DeleteProfile", GetLastError());
-		goto cleanup; 
-	}
-	d(g_print("succeeded \n"));
-
-	retval = ProcessNetworkProfile(session, username, NULL, NULL); 
-	if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("ProcessNetworkProfile", GetLastError());
-		goto cleanup; 
-	}
-
-	/* Set it as the default profile. Is this needed? */
-	retval = SetDefaultProfile(profname); 
-	if (retval != MAPI_E_SUCCESS) {
-		mapi_errstr("SetDefaultProfile", GetLastError());
-		goto cleanup; 
-	}
-
-	/* Close the connection, so that we can login with what we created */
-	exchange_mapi_connection_close ();
-
-	/* Initialize a global connection */
-	if (exchange_mapi_connection_new (profname, password)) {
-		result = TRUE;
-		exchange_mapi_account_listener_get_folder_list ();
-	}
-
-cleanup: 
-	if (!result)
-		MAPIUninitialize ();
-
-	g_free (profname);
-	g_free (profpath);
-
-	return result;
-}
-
-
 static void
 validate_credentials (GtkWidget *widget, EConfig *config)
 {
 	EMConfigTargetAccount *target_account = (EMConfigTargetAccount *)(config->target);
 	CamelURL *url = NULL;
  	gchar *key = NULL, *password = NULL;
+	const gchar *domain_name = NULL; 
 
 	url = camel_url_new (e_account_get_string (target_account->account, E_ACCOUNT_SOURCE_URL), NULL);
+	domain_name = camel_url_get_param (url, "domain");
+
+	if (!url->user || !*url->user || !url->host || !*url->host || !domain_name || !*domain_name) {
+		e_notice (NULL, GTK_MESSAGE_ERROR, "%s", _("Server, username and domain name cannot be empty. Please fill them with correct values."));
+		return;
+	}
+
 	key = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
 	password = e_passwords_get_password (EXCHANGE_MAPI_PASSWORD_COMPONENT, key);
 	if (!password) {
@@ -252,9 +123,10 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 		g_free (title);
 	}
 
-	if (password) {
-		const gchar *domain_name = camel_url_get_param (url, "domain");
-		gboolean status = exchange_mapi_create_profile (url->user, password, domain_name, url->host);
+	/*Can there be a account without password ?*/
+	if (password && *password && domain_name && *domain_name && *url->user && *url->host) {
+		char *error_msg = NULL;
+		gboolean status = exchange_mapi_create_profile (url->user, password, domain_name, url->host, &error_msg);
 		if (status) {
 			/* Things are successful */
 			gchar *profname = NULL, *uri = NULL; 
@@ -264,12 +136,24 @@ validate_credentials (GtkWidget *widget, EConfig *config)
 			g_free (profname);
 
 			uri = camel_url_to_string(url, 0);
-			e_account_set_string(target_account->account, E_ACCOUNT_SOURCE_URL, uri);
+			e_account_set_string (target_account->account, E_ACCOUNT_SOURCE_URL, uri);
+			e_account_set_string (target_account->account, E_ACCOUNT_TRANSPORT_URL, uri);
 			g_free (uri);
+
+			e_notice (NULL, GTK_MESSAGE_INFO, "%s", _("Authentication finished successfully."));
 		} else {
+			char *e;
+
 			e_passwords_forget_password (EXCHANGE_MAPI_PASSWORD_COMPONENT, key);
-			/* FIXME: Run an error dialog here */
+
+			e = g_strconcat (_("Authentication failed."), "\n", error_msg, NULL);
+
+			e_notice (NULL, GTK_MESSAGE_ERROR, "%s", e);
+
+			g_free (e);
 		}
+
+		g_free (error_msg);
 	}
 
 	g_free (password);
@@ -295,6 +179,7 @@ domain_entry_changed(GtkWidget *entry, EConfig *config)
 
 	url_string = camel_url_to_string (url, 0);
 	e_account_set_string (target->account, E_ACCOUNT_SOURCE_URL, url_string);
+	e_account_set_string (target->account, E_ACCOUNT_TRANSPORT_URL, url_string);
 	g_free (url_string);
 
 	camel_url_free (url);
@@ -310,12 +195,15 @@ org_gnome_exchange_mapi_account_setup (EPlugin *epl, EConfigHookItemFactoryData
 	target_account = (EMConfigTargetAccount *)data->config->target;
 	url = camel_url_new(e_account_get_string(target_account->account, E_ACCOUNT_SOURCE_URL), NULL);
 
-	g_return_val_if_fail (url != NULL, NULL); 
+	/* is NULL on New Account creation */
+	if (url == NULL)
+		return NULL; 
 
 	if (!g_ascii_strcasecmp (url->protocol, "mapi")) {
 		GtkWidget *label;
 		GtkWidget *domain_name;
 		GtkWidget *auth_button;
+		const char *domain_value = camel_url_get_param (url, "domain");
 		int row = ((GtkTable *)data->parent)->nrows;
 
 		/* Domain name & Authenticate Button */
@@ -325,6 +213,8 @@ org_gnome_exchange_mapi_account_setup (EPlugin *epl, EConfigHookItemFactoryData
 
 		domain_name = gtk_entry_new ();
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), domain_name);
+		if (domain_value && *domain_value)
+			gtk_entry_set_text (GTK_ENTRY (domain_name), domain_value);
 		gtk_box_pack_start (GTK_BOX (hbox), domain_name, FALSE, FALSE, 0);
 		g_signal_connect (domain_name, "changed", G_CALLBACK(domain_entry_changed), data->config);
 
@@ -338,7 +228,7 @@ org_gnome_exchange_mapi_account_setup (EPlugin *epl, EConfigHookItemFactoryData
 	}
 
 	camel_url_free (url);
-	return GTK_WIDGET (hbox);
+	return hbox;
 }
 
 gboolean
@@ -380,10 +270,13 @@ enum {
 static gboolean
 check_node (GtkTreeStore *ts, ExchangeMAPIFolder *folder, GtkTreeIter *iter)
 {
+	GtkTreeModel *ts_model;
 	mapi_id_t fid;
 	gboolean status = FALSE;
+
+	ts_model = GTK_TREE_MODEL (ts);
 	
-	gtk_tree_model_get (GTK_TREE_MODEL (ts), iter, 1, &fid, -1);
+	gtk_tree_model_get (ts_model, iter, 1, &fid, -1);
 	if (fid && folder->parent_folder_id == fid) {
 		/* Do something */
 		GtkTreeIter node;
@@ -392,13 +285,13 @@ check_node (GtkTreeStore *ts, ExchangeMAPIFolder *folder, GtkTreeIter *iter)
 		return TRUE;
 	}
 
-	if (gtk_tree_model_iter_has_child (ts, iter)) {
+	if (gtk_tree_model_iter_has_child (ts_model, iter)) {
 		GtkTreeIter child;
-		gtk_tree_model_iter_children (ts, &child, iter);
+		gtk_tree_model_iter_children (ts_model, &child, iter);
 		status = check_node (ts, folder, &child);
 	}
 
-	while (gtk_tree_model_iter_next (ts, iter) && !status) {
+	while (gtk_tree_model_iter_next (ts_model, iter) && !status) {
 		status = check_node (ts, folder, iter);
 	}
 
@@ -408,9 +301,12 @@ check_node (GtkTreeStore *ts, ExchangeMAPIFolder *folder, GtkTreeIter *iter)
 static void
 add_to_store (GtkTreeStore *ts, ExchangeMAPIFolder *folder)
 {
+	GtkTreeModel *ts_model;
 	GtkTreeIter iter;
+
+	ts_model = GTK_TREE_MODEL (ts);
 	
-	gtk_tree_model_get_iter_first (ts, &iter);
+	gtk_tree_model_get_iter_first (ts_model, &iter);
 	if (!check_node (ts, folder, &iter)) {
 		GtkTreeIter node;
 		gtk_tree_store_append (ts, &node, &iter);		
@@ -636,7 +532,7 @@ exchange_mapi_cal_commit (EPlugin *epl, EConfigTarget *target)
 			type = olFolderNotes; 
 			break;
 		default: 
-			g_warning ("%s(%d): %s: Unknown ExchangeMAPIFolderType\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+			g_warning ("%s: %s: Unknown ExchangeMAPIFolderType\n", G_STRLOC, G_STRFUNC);
 			return;
 	}
 
