@@ -68,7 +68,7 @@
 #include <libmapi/libmapi.h>
 #include <param.h>
 
-#define d(x) printf("%s(%d):%s:%s \n", __FILE__, __LINE__, __PRETTY_FUNCTION__, x)
+#define d(x) printf("%s:%s:%s \n", G_STRLOC, G_STRFUNC, x)
 
 struct _CamelMapiStorePrivate {
 	char *user;
@@ -261,6 +261,8 @@ static char
 	if (brief) {
 		return g_strdup_printf(_("Exchange MAPI server %s"), service->url->host);
 	} else {
+		/*To translators : Example string : Exchange MAPI service for 
+		  _username_ on _server host name__*/
 		return g_strdup_printf(_("Exchange MAPI service for %s on %s"),
 				       service->url->user, service->url->host);
 	}
@@ -295,8 +297,11 @@ mapi_auth_loop (CamelService *service, CamelException *ex)
 		if (!service->url->passwd ){
 			char *prompt;
 			
-			prompt = g_strdup_printf (_("%sPlease enter the MAPI "
-						    "password for %s@%s"),
+			/*To translators : First %s : is the error text or the reason
+			  for prompting the user if it is available.
+			 Second %s is : Username.
+			 Third %s is : Server host name.*/
+			prompt = g_strdup_printf (_("%s Please enter the MAPI password for %s@%s"),
 						  errbuf ? errbuf : "",
 						  service->url->user,
 						  service->url->host);
@@ -494,25 +499,14 @@ mapi_forget_folder (CamelMapiStore *mapi_store, const char *folder_name, CamelEx
 	storage_path = g_strdup_printf ("%s/folders", priv->storage_path);
 
 	/* Fixme Path - e_*-to_path */
-	folder_dir = g_strdup(g_strconcat (storage_path, "/", folder_name, NULL));
+	folder_dir = g_strconcat (storage_path, "/", folder_name, NULL);
+	g_free (storage_path);
 
 	if (g_access(folder_dir, F_OK) != 0) {
 		g_free(folder_dir);
 		return;
 	}
 
-	summary_file = g_strdup_printf ("%s/summary", folder_dir);
-	summary = camel_mapi_summary_new(NULL,summary_file);
-	if(!summary) {
-		g_free(summary_file);
-		g_free(folder_dir);
-		return;
-	}
-
-	camel_object_unref (summary);
-	g_unlink (summary_file);
-	g_free (summary_file);
-
 	state_file = g_strdup_printf ("%s/cmeta", folder_dir);
 	g_unlink (state_file);
 	g_free (state_file);
@@ -638,6 +632,7 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 {
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 	CamelMapiStorePrivate  *priv = mapi_store->priv;
+	CamelStoreInfo *si = NULL;
 	char *oldpath, *newpath, *storepath;
 	const char *folder_id;
 	char *temp = NULL;
@@ -659,7 +654,9 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	folder_id = camel_mapi_store_folder_id_lookup (mapi_store, temp);
 	if (!folder_id) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s'. Folder does not exist."),
+		/*To translators : '%s' is current name of the folder */
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI folder `%s'. Folder does not exist."),
 				      old_name);
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		return;
@@ -667,12 +664,14 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	/*Do not allow rename for system folders.*/
 	if (mapi_fid_is_system_folder (mapi_store, folder_id)) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s' to `%s'. Default folder."),
+		/*To translators : '%s to %s' is current name of the folder  and
+		 new name of the folder.*/
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI default folder `%s' to `%s'."),
 				      old_name, new_name);
 		return;
 	}
 
-
 	exchange_mapi_util_mapi_id_from_string (folder_id, &fid);
 		
 	temp = strrchr (new_name, '/');
@@ -683,12 +682,17 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 	
 	if (!exchange_mapi_rename_folder (fid , temp))
 	{
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename MAPI folder `%s' to `%s'"),
-				      old_name, new_name);
+		/*To translators : '%s to %s' is current name of the folder  and
+		 new name of the folder.*/
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
+				      _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
+
 		CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
 		return;
 	}
 
+	CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
+
 	g_hash_table_replace (priv->id_hash, g_strdup(folder_id), g_strdup(temp));
 
 	g_hash_table_insert (priv->name_hash, g_strdup(new_name), g_strdup(folder_id));
@@ -700,6 +704,17 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 	g_free (storepath);
 
 	/*XXX: make sure the summary is also renamed*/
+	si = camel_store_summary_path ((CamelStoreSummary *)mapi_store->summary, old_name);
+
+	if (si) {
+		camel_store_info_set_string((CamelStoreSummary *)mapi_store->summary, si,
+					    CAMEL_STORE_INFO_PATH, new_name);
+		camel_store_info_set_string((CamelStoreSummary *)mapi_store->summary, si,
+					    CAMEL_MAPI_STORE_INFO_FULL_NAME, new_name);
+
+		camel_store_summary_touch((CamelStoreSummary *)mapi_store->summary);
+	}
+
 	if (g_rename (oldpath, newpath) == -1) {
 		g_warning ("Could not rename message cache '%s' to '%s': %s: cache reset",
 				oldpath, newpath, strerror (errno));
@@ -707,7 +722,7 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	g_free (oldpath);
 	g_free (newpath);
-	CAMEL_SERVICE_REC_UNLOCK (mapi_store, connect_lock);
+
 }
 
 static guint32 hexnib(guint32 c)
@@ -853,10 +868,11 @@ mapi_build_folder_info(CamelMapiStore *mapi_store, const char *parent_name, cons
 		fi->full_name = g_strdup(folder_name);
  
 	url = camel_url_new(priv->base_url,NULL);
-	//g_free(url->path);
+	g_free(url->path);
+
 	url->path = g_strdup_printf("/%s", fi->full_name);
 	fi->uri = camel_url_to_string(url,CAMEL_URL_HIDE_ALL);
-	//camel_url_free(url);
+	camel_url_free(url);
 
 	name = strrchr(fi->full_name,'/');
 	if(name == NULL)
@@ -952,7 +968,7 @@ mapi_get_folder_info_offline (CamelStore *store, const char *top,
 	}
 
 	/*FIXME*/
-	if (!((!subscribed) && info_fast) ) {
+	if (!((!subscribed) && info_fast) && top[0] == '\0') {
 		fi = mapi_build_folder_info(mapi_store, NULL, DISPLAY_NAME_FAVOURITES);
 		fi->flags |= CAMEL_FOLDER_NOSELECT;
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
@@ -998,7 +1014,12 @@ mapi_convert_to_folder_info (CamelMapiStore *store, ExchangeMAPIFolder *folder,
 		case olFolderDeletedItems:
 			fi->flags |= CAMEL_FOLDER_TYPE_TRASH;
 			break;
-		/*TODO : case olFolderJunkMail */
+		case olFolderOutbox:
+			fi->flags |= CAMEL_FOLDER_TYPE_OUTBOX;
+			break;
+		case olFolderJunk:
+			fi->flags |= CAMEL_FOLDER_TYPE_JUNK;
+			break;
 		}
 
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
@@ -1148,7 +1169,7 @@ mapi_folders_sync (CamelMapiStore *store, CamelException *ex)
 	for (;folder_list != NULL; folder_list = g_slist_next (folder_list)) {
 		ExchangeMAPIFolder *folder = (ExchangeMAPIFolder *) folder_list->data;
 		
-		if (exchange_mapi_folder_is_root ((ExchangeMAPIFolder *)(folder)))
+		if (folder->default_type == olPublicFoldersAllPublicFolders)
 			continue;
 
 		if ( folder->container_class != MAPI_FOLDER_TYPE_MAIL) 
@@ -1253,13 +1274,14 @@ mapi_subscribe_folder(CamelStore *store, const char *folder_name, CamelException
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 
 	CamelFolderInfo *fi;
-	CamelStoreInfo *si;
+	CamelStoreInfo *si = NULL;
 	gchar *parent_name = NULL;
 	gchar *f_name = NULL;
 	CamelURL *url;
 	/* TODO : exchange_mapi_add_to_favorites (); */
 
-	if (si = camel_store_summary_path((CamelStoreSummary *)mapi_store->summary, folder_name)) {
+	si = camel_store_summary_path((CamelStoreSummary *)mapi_store->summary, folder_name);
+	if (si != NULL) {
 		if ((si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) == 0) {
 			si->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
 			si->flags |= CAMEL_FOLDER_SUBSCRIBED;
@@ -1274,6 +1296,8 @@ mapi_subscribe_folder(CamelStore *store, const char *folder_name, CamelException
 		f_name = strrchr(folder_name,'/');
 		if(f_name != NULL)
 			folder_name = ++f_name;
+		else  //Don't process All Public Folder.
+			return;
 	}
 
 	fi = mapi_build_folder_info(mapi_store, parent_name, g_strdup (folder_name)); /* FIXME */
@@ -1331,6 +1355,8 @@ mapi_unsubscribe_folder(CamelStore *store, const char *folder_name, CamelExcepti
 		f_name = strrchr(folder_name,'/');
 		if(f_name != NULL)
 			folder_name = ++f_name;
+		else //Don't process All Public Folder.
+			return;
 	}
 
 	fi = mapi_build_folder_info(mapi_store, parent_name, g_strdup (folder_name)); /* FIXME */
